@@ -91,7 +91,11 @@ def isValidSPECFile(path: str) -> bool:
         spec_data = spec.SpecDataFile(path)
         return True
     except:
-        return False
+        try:
+            spec_data = spec.SpecDataFile(path)
+            return True
+        except:
+            return False
 
 
 def isValidInstrumentXMLFile(path: str) -> bool:
